@@ -1,4 +1,4 @@
-import { AsyncThunk, createAsyncThunk } from '@reduxjs/toolkit';
+import { createAsyncThunk } from '@reduxjs/toolkit';
 import { isEmpty } from 'lodash';
 
 import { locationService } from '@grafana/runtime';
@@ -10,7 +10,7 @@ import {
   Receiver,
   TestReceiversAlert,
 } from 'app/plugins/datasource/alertmanager/types';
-import { FolderDTO, NotifierDTO, StoreState, ThunkResult } from 'app/types';
+import { FolderDTO, StoreState, ThunkResult } from 'app/types';
 import {
   CombinedRuleGroup,
   CombinedRuleNamespace,
@@ -49,17 +49,9 @@ import {
 import { alertmanagerApi } from '../api/alertmanagerApi';
 import { fetchAnnotations } from '../api/annotations';
 import { discoverFeatures } from '../api/buildInfo';
-import { fetchNotifiers } from '../api/grafana';
 import { FetchPromRulesFilter, fetchRules } from '../api/prometheus';
-import {
-  FetchRulerRulesFilter,
-  deleteNamespace,
-  deleteRulerRulesGroup,
-  fetchRulerRules,
-  setRulerRuleGroup,
-} from '../api/ruler';
-import { encodeGrafanaNamespace } from '../components/expressions/util';
-import { RuleFormType, RuleFormValues } from '../types/rule-form';
+import { FetchRulerRulesFilter, deleteRulerRulesGroup, fetchRulerRules, setRulerRuleGroup } from '../api/ruler';
+import { RuleFormValues } from '../types/rule-form';
 import { addDefaultsToAlertmanagerConfig, removeMuteTimingFromRoute } from '../utils/alertmanager';
 import {
   GRAFANA_RULES_SOURCE_NAME,
@@ -71,20 +63,34 @@ import { makeAMLink } from '../utils/misc';
 import { AsyncRequestMapSlice, withAppEvents, withSerializedError } from '../utils/redux';
 import * as ruleId from '../utils/rule-id';
 import { getRulerClient } from '../utils/rulerClient';
-import { getAlertInfo, isGrafanaRulerRule, isRulerNotSupportedResponse } from '../utils/rules';
+import {
+  getAlertInfo,
+  isDataSourceManagedRuleByType,
+  isGrafanaManagedRuleByType,
+  isGrafanaRulerRule,
+  isRulerNotSupportedResponse,
+} from '../utils/rules';
 import { safeParsePrometheusDuration } from '../utils/time';
 
 function getDataSourceConfig(getState: () => unknown, rulesSourceName: string) {
   const dataSources = (getState() as StoreState).unifiedAlerting.dataSources;
   const dsConfig = dataSources[rulesSourceName]?.result;
+  const dsError = dataSources[rulesSourceName]?.error;
+
+  // @TODO use aggregateError but add support for it in "stringifyErrorLike"
   if (!dsConfig) {
-    throw new Error(`Data source configuration is not available for "${rulesSourceName}" data source`);
+    const error = new Error(`Data source configuration is not available for "${rulesSourceName}" data source`);
+    if (dsError) {
+      error.cause = dsError;
+    }
+
+    throw error;
   }
 
   return dsConfig;
 }
 
-function getDataSourceRulerConfig(getState: () => unknown, rulesSourceName: string) {
+export function getDataSourceRulerConfig(getState: () => unknown, rulesSourceName: string) {
   const dsConfig = getDataSourceConfig(getState, rulesSourceName);
   if (!dsConfig.rulerConfig) {
     throw new Error(`Ruler API is not available for ${rulesSourceName}`);
@@ -335,41 +341,6 @@ export function deleteRulesGroupAction(
   };
 }
 
-export function deleteRuleAction(
-  ruleIdentifier: RuleIdentifier,
-  options: { navigateTo?: string } = {}
-): ThunkResult<void> {
-  /*
-   * fetch the rules group from backend, delete group if it is found and+
-   * reload ruler rules
-   */
-  return async (dispatch, getState) => {
-    await dispatch(fetchRulesSourceBuildInfoAction({ rulesSourceName: ruleIdentifier.ruleSourceName }));
-
-    withAppEvents(
-      (async () => {
-        const rulerConfig = getDataSourceRulerConfig(getState, ruleIdentifier.ruleSourceName);
-        const rulerClient = getRulerClient(rulerConfig);
-        const ruleWithLocation = await rulerClient.findEditableRule(ruleIdentifier);
-
-        if (!ruleWithLocation) {
-          throw new Error('Rule not found.');
-        }
-        await rulerClient.deleteRule(ruleWithLocation);
-        // refetch rules for this rules source
-        await dispatch(fetchPromAndRulerRulesAction({ rulesSourceName: ruleWithLocation.ruleSourceName }));
-
-        if (options.navigateTo) {
-          locationService.replace(options.navigateTo);
-        }
-      })(),
-      {
-        successMessage: 'Rule deleted.',
-      }
-    );
-  };
-}
-
 export const saveRuleFormAction = createAsyncThunk(
   'unifiedalerting/saveRuleForm',
   (
@@ -391,13 +362,16 @@ export const saveRuleFormAction = createAsyncThunk(
       withSerializedError(
         (async () => {
           const { type } = values;
+          if (!type) {
+            return;
+          }
 
           // TODO getRulerConfig should be smart enough to provide proper rulerClient implementation
           // For the dataSourceName specified
           // in case of system (cortex/loki)
           let identifier: RuleIdentifier;
 
-          if (type === RuleFormType.cloudAlerting || type === RuleFormType.cloudRecording) {
+          if (isDataSourceManagedRuleByType(type)) {
             if (!values.dataSourceName) {
               throw new Error('The Data source has not been defined.');
             }
@@ -406,8 +380,8 @@ export const saveRuleFormAction = createAsyncThunk(
             const rulerClient = getRulerClient(rulerConfig);
             identifier = await rulerClient.saveLotexRule(values, evaluateEvery, existing);
             await thunkAPI.dispatch(fetchRulerRulesAction({ rulesSourceName: values.dataSourceName }));
-            // in case of grafana managed
-          } else if (type === RuleFormType.grafana) {
+            // in case of grafana managed rules or grafana-managed recording rules
+          } else if (isGrafanaManagedRuleByType(type)) {
             const rulerConfig = getDataSourceRulerConfig(thunkAPI.getState, GRAFANA_RULES_SOURCE_NAME);
             const rulerClient = getRulerClient(rulerConfig);
             identifier = await rulerClient.saveGrafanaRule(values, evaluateEvery, existing);
@@ -462,11 +436,6 @@ function reportSwitchingRoutingType(values: RuleFormValues, existingRule: RuleWi
   }
 }
 
-export const fetchGrafanaNotifiersAction = createAsyncThunk(
-  'unifiedalerting/fetchGrafanaNotifiers',
-  (): Promise<NotifierDTO[]> => withSerializedError(fetchNotifiers())
-);
-
 export const fetchGrafanaAnnotationsAction = createAsyncThunk(
   'unifiedalerting/fetchGrafanaAnnotations',
   (alertId: string): Promise<StateHistoryItem[]> => withSerializedError(fetchAnnotations(alertId))
@@ -550,39 +519,6 @@ export const deleteReceiverAction = (receiverName: string, alertManagerSourceNam
   };
 };
 
-export const deleteTemplateAction = (templateName: string, alertManagerSourceName: string): ThunkResult<void> => {
-  return async (dispatch) => {
-    const config = await dispatch(
-      alertmanagerApi.endpoints.getAlertmanagerConfiguration.initiate(alertManagerSourceName)
-    ).unwrap();
-
-    if (!config) {
-      throw new Error(`Config for ${alertManagerSourceName} not found`);
-    }
-    if (typeof config.template_files?.[templateName] !== 'string') {
-      throw new Error(`Cannot delete template ${templateName}: not found in config.`);
-    }
-    const newTemplates = { ...config.template_files };
-    delete newTemplates[templateName];
-    const newConfig: AlertManagerCortexConfig = {
-      ...config,
-      alertmanager_config: {
-        ...config.alertmanager_config,
-        templates: config.alertmanager_config.templates?.filter((existing) => existing !== templateName),
-      },
-      template_files: newTemplates,
-    };
-    return dispatch(
-      updateAlertManagerConfigAction({
-        newConfig,
-        oldConfig: config,
-        alertManagerSourceName,
-        successMessage: 'Template deleted.',
-      })
-    );
-  };
-};
-
 export const fetchFolderAction = createAsyncThunk(
   'unifiedalerting/fetchFolder',
   (uid: string): Promise<FolderDTO> => withSerializedError(backendSrv.getFolderByUid(uid, { withAccessControl: true }))
@@ -643,31 +579,29 @@ export const deleteMuteTimingAction = (alertManagerSourceName: string, muteTimin
           mute_time_intervals: muteIntervalsFiltered,
         };
 
-    if (config) {
-      const { mute_time_intervals: _, ...configWithoutMuteTimings } = config?.alertmanager_config ?? {};
-      withAppEvents(
-        dispatch(
-          updateAlertManagerConfigAction({
-            alertManagerSourceName,
-            oldConfig: config,
-            newConfig: {
-              ...config,
-              alertmanager_config: {
-                ...configWithoutMuteTimings,
-                route: config.alertmanager_config.route
-                  ? removeMuteTimingFromRoute(muteTimingName, config.alertmanager_config?.route)
-                  : undefined,
-                ...time_intervals_without_mute_to_save,
-              },
+    const { mute_time_intervals: _, ...configWithoutMuteTimings } = config?.alertmanager_config ?? {};
+    return withAppEvents(
+      dispatch(
+        updateAlertManagerConfigAction({
+          alertManagerSourceName,
+          oldConfig: config,
+          newConfig: {
+            ...config,
+            alertmanager_config: {
+              ...configWithoutMuteTimings,
+              route: config.alertmanager_config.route
+                ? removeMuteTimingFromRoute(muteTimingName, config.alertmanager_config?.route)
+                : undefined,
+              ...time_intervals_without_mute_to_save,
             },
-          })
-        ),
-        {
-          successMessage: `Deleted "${muteTimingName}" from Alertmanager configuration`,
-          errorMessage: 'Failed to delete mute timing',
-        }
-      );
-    }
+          },
+        })
+      ),
+      {
+        successMessage: `Deleted "${muteTimingName}" from Alertmanager configuration`,
+        errorMessage: 'Failed to delete mute timing',
+      }
+    );
   };
 };
 
@@ -687,143 +621,16 @@ export const testReceiversAction = createAsyncThunk(
   }
 );
 
-interface UpdateNamespaceAndGroupOptions {
-  rulesSourceName: string;
-  namespaceName: string;
-  groupName: string;
-  newNamespaceName: string;
-  newGroupName: string;
-  groupInterval?: string;
-  folderUid?: string;
-}
-
 export const rulesInSameGroupHaveInvalidFor = (rules: RulerRuleDTO[], everyDuration: string) => {
   return rules.filter((rule: RulerRuleDTO) => {
     const { forDuration } = getAlertInfo(rule, everyDuration);
-    const forNumber = safeParsePrometheusDuration(forDuration);
+    const forNumber = forDuration ? safeParsePrometheusDuration(forDuration) : null;
     const everyNumber = safeParsePrometheusDuration(everyDuration);
 
-    return forNumber !== 0 && forNumber < everyNumber;
+    return forNumber ? forNumber !== 0 && forNumber < everyNumber : false;
   });
 };
 
-// allows renaming namespace, renaming group and changing group interval, all in one go
-export const updateLotexNamespaceAndGroupAction: AsyncThunk<
-  void,
-  UpdateNamespaceAndGroupOptions,
-  { state: StoreState }
-> = createAsyncThunk<void, UpdateNamespaceAndGroupOptions, { state: StoreState }>(
-  'unifiedalerting/updateLotexNamespaceAndGroup',
-  async (options: UpdateNamespaceAndGroupOptions, thunkAPI): Promise<void> => {
-    return withAppEvents(
-      withSerializedError(
-        (async () => {
-          const {
-            rulesSourceName,
-            namespaceName,
-            groupName,
-            newNamespaceName,
-            newGroupName,
-            groupInterval,
-            folderUid,
-          } = options;
-
-          const rulerConfig = getDataSourceRulerConfig(thunkAPI.getState, rulesSourceName);
-          // fetch rules and perform sanity checks
-          const rulesResult = await fetchRulerRules(rulerConfig);
-
-          const existingNamespace = Boolean(rulesResult[namespaceName]);
-
-          if (!existingNamespace) {
-            throw new Error(`Namespace "${namespaceName}" not found.`);
-          }
-
-          const existingGroup = rulesResult[namespaceName].find((group) => group.name === groupName);
-          if (!existingGroup) {
-            throw new Error(`Group "${groupName}" not found.`);
-          }
-
-          const newGroupAlreadyExists = Boolean(
-            rulesResult[namespaceName].find((group) => group.name === newGroupName)
-          );
-
-          if (newGroupName !== groupName && newGroupAlreadyExists) {
-            throw new Error(`Group "${newGroupName}" already exists in namespace "${namespaceName}".`);
-          }
-
-          const newNamespaceAlreadyExists = Boolean(rulesResult[newNamespaceName]);
-          const isGrafanaManagedGroup = rulesSourceName === GRAFANA_RULES_SOURCE_NAME;
-          const originalNamespace = isGrafanaManagedGroup ? encodeGrafanaNamespace(namespaceName) : namespaceName;
-
-          if (newNamespaceName !== originalNamespace && newNamespaceAlreadyExists) {
-            throw new Error(`Namespace "${newNamespaceName}" already exists.`);
-          }
-          if (
-            newNamespaceName === originalNamespace &&
-            groupName === newGroupName &&
-            groupInterval === existingGroup.interval
-          ) {
-            throw new Error('Nothing changed.');
-          }
-
-          // validation for new groupInterval
-          if (groupInterval !== existingGroup.interval) {
-            const notValidRules = rulesInSameGroupHaveInvalidFor(existingGroup.rules, groupInterval ?? '1m');
-            if (notValidRules.length > 0) {
-              throw new Error(
-                `These alerts belonging to this group will have an invalid 'For' value: ${notValidRules
-                  .map((rule) => {
-                    const { alertName } = getAlertInfo(rule, groupInterval ?? '');
-                    return alertName;
-                  })
-                  .join(',')}`
-              );
-            }
-          }
-          // if renaming namespace - make new copies of all groups, then delete old namespace
-          // this is only possible for cloud rules
-          if (newNamespaceName !== originalNamespace) {
-            for (const group of rulesResult[namespaceName]) {
-              await setRulerRuleGroup(
-                rulerConfig,
-                newNamespaceName,
-                group.name === groupName
-                  ? {
-                      ...group,
-                      name: newGroupName,
-                      interval: groupInterval,
-                    }
-                  : group
-              );
-            }
-            await deleteNamespace(rulerConfig, folderUid || namespaceName);
-
-            // if only modifying group...
-          } else {
-            // save updated group
-            await setRulerRuleGroup(rulerConfig, folderUid || namespaceName, {
-              ...existingGroup,
-              name: newGroupName,
-              interval: groupInterval,
-            });
-            // if group name was changed, delete old group
-            if (newGroupName !== groupName) {
-              await deleteRulerRulesGroup(rulerConfig, folderUid || namespaceName, groupName);
-            }
-          }
-
-          // refetch all rules
-          await thunkAPI.dispatch(fetchRulerRulesAction({ rulesSourceName }));
-        })()
-      ),
-      {
-        errorMessage: 'Failed to update namespace / group',
-        successMessage: 'Update successful',
-      }
-    );
-  }
-);
-
 interface UpdateRulesOrderOptions {
   rulesSourceName: string;
   namespaceName: string;
